@@ -21,17 +21,24 @@
 
 #include "KMixApp.h"
 
-#include <kcmdlineargs.h>
-#include <kdebug.h>
+#include <qapplication.h>
+#include <qcommandlineparser.h>
 
 #include "apps/kmix.h"
 #include "core/ControlManager.h"
 #include "core/GlobalConfig.h"
 
-bool KMixApp::firstCaller = true;
+static bool firstCaller = true;
 
-KMixApp::KMixApp() :
-		KUniqueApplication(), m_kmix(0), creationLock(QMutex::Recursive)
+// Originally this class was a subclass of KUniqueApplication.
+// Since, now that a unique application is enforced earlier by KDBusService,
+// the only purpose of this class is to receive the activateRequested()
+// signal.  It can therefore be a simple QObject.
+
+KMixApp::KMixApp()
+	: QObject(),
+	  m_kmix(0),
+	  creationLock(QMutex::Recursive)
 {
 	GlobalConfig::init();
 
@@ -41,12 +48,12 @@ KMixApp::KMixApp() :
 	// 2b) The dock icon gets reconstructed, when the user selects a new master.
 	// 3) During the reconstruction, it can easily happen that no window is present => KMix would quit
 	// => disable QuitOnLastWindowClosed
-	setQuitOnLastWindowClosed(false);
+	qApp->setQuitOnLastWindowClosed(false);
 }
 
 KMixApp::~KMixApp()
 {
-	kDebug() << "Deleting KMixApp";
+	qCDebug(KMIX_LOG) << "Deleting KMixApp";
 	ControlManager::instance().shutdownNow();
 	delete m_kmix;
 	m_kmix = 0;
@@ -58,7 +65,7 @@ void KMixApp::createWindowOnce(bool hasArgKeepvisibility, bool reset)
 	// Create window, if it was not yet created (e.g. via autostart or manually)
 	if (m_kmix == 0)
 	{
-		kDebug() << "Creating new KMix window";
+		qCDebug(KMIX_LOG) << "Creating new KMix window";
 		m_kmix = new KMixWindow(hasArgKeepvisibility, reset);
 	}
 }
@@ -80,24 +87,24 @@ bool KMixApp::restoreSessionIfApplicable(bool hasArgKeepvisibility, bool reset)
 	 */
 	creationLock.lock();
 
-	bool restore = isSessionRestored(); // && KMainWindow::canBeRestored(0);
-	kDebug() << "Starting KMix using kepvisibility=" << hasArgKeepvisibility << ", failsafe=" << reset << ", sessionRestore=" << restore;
+	bool restore = qApp->isSessionRestored(); // && KMainWindow::canBeRestored(0);
+	qCDebug(KMIX_LOG) << "Starting KMix using keepvisibility=" << hasArgKeepvisibility << ", failsafe=" << reset << ", sessionRestore=" << restore;
 	int createCount = 0;
 	if (restore)
 	{
 		if (reset)
 		{
-			kWarning() << "Reset cannot be performed while KMix is running. Please quit KMix and retry then.";
+			qCWarning(KMIX_LOG) << "Reset cannot be performed while KMix is running. Please quit KMix and retry then.";
 		}
 		int n = 1;
 		while (KMainWindow::canBeRestored(n))
 		{
-			kDebug() << "Restoring window " << n;
+			qCDebug(KMIX_LOG) << "Restoring window " << n;
 			if (n > 1)
 			{
 				// This code path is "impossible". It is here only for analyzing possible issues with session resoring.
 				// KMix is a single-instance app. If more than one instance is craeated we have a bug.
-				kWarning() << "KDE session management wants to restore multiple instances of KMix. Please report this as a bug.";
+				qCWarning(KMIX_LOG) << "KDE session management wants to restore multiple instances of KMix. Please report this as a bug.";
 				break;
 			}
 			else
@@ -122,11 +129,9 @@ bool KMixApp::restoreSessionIfApplicable(bool hasArgKeepvisibility, bool reset)
 	return restore;
 }
 
-int KMixApp::newInstance()
+void KMixApp::newInstance(const QStringList &arguments, const QString &workingDirectory)
 {
-	KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
-	bool hasArgKeepvisibility = args->isSet("keepvisibility");
-	bool reset = args->isSet("failsafe");
+	qDebug();
 
 	/**
 	 * There are 3 cases when starting KMix:
@@ -138,7 +143,7 @@ int KMixApp::newInstance()
 	 */
 
 
-	//kDebug(67100) <<  "KMixApp::newInstance() isRestored()=" << isRestored() << "_keepVisibility=" << _keepVisibility;
+	//qCDebug(KMIX_LOG) <<  "KMixApp::newInstance() isRestored()=" << isRestored() << "_keepVisibility=" << _keepVisibility;
 	/**
 	 * 		NB See https://qa.mandriva.com/show_bug.cgi?id=56893#c3
 	 *
@@ -158,12 +163,11 @@ int KMixApp::newInstance()
 		 * Typical case: Normal start. KMix was not running yet => create a new KMixWindow
 		 */
 		GlobalConfig::init();
-		restoreSessionIfApplicable(hasArgKeepvisibility, reset);
-
+		restoreSessionIfApplicable(m_hasArgKeepvisibility, m_hasArgReset);
 	}
 	else
 	{
-		if (!hasArgKeepvisibility)
+		if (!m_hasArgKeepvisibility)
 		{
 			/** CASE 2 ******************************************************
 			 *
@@ -179,14 +183,14 @@ int KMixApp::newInstance()
 			 * 2) Session restore => we are here at this line of code (CASE 2). m_kmix exists, but still must be restored
 			 *
 			 */
-			bool wasRestored = restoreSessionIfApplicable(hasArgKeepvisibility, reset);
-
+			bool wasRestored = restoreSessionIfApplicable(m_hasArgKeepvisibility, m_hasArgReset);
 			if (!wasRestored)
 			{
 				//
 				// Use standard newInstances(), which shows and activates the main window. But skip it for the
 				// special "restored" case, as we should not override the session rules.
-				KUniqueApplication::newInstance();
+				// TODO: what should be done for KF5?
+				//KUniqueApplication::newInstance();
 			}
 			// else: Do nothing, as session restore has done it.
 		}
@@ -204,15 +208,18 @@ int KMixApp::newInstance()
 			 *       (see BKO 58901), but nowadays Mixer Applets nmight want to use it, though they should
 			 *       use KMixD instead.
 			 */
-			kDebug()
+			qCDebug(KMIX_LOG)
 			<< "KMixApp::newInstance() REGULAR_START _keepVisibility="
-					<< hasArgKeepvisibility;
+					<< m_hasArgKeepvisibility;
 		}
 	}
 
 	creationLock.unlock();
-
-	return 0;
 }
 
 
+void KMixApp::parseOptions(const QCommandLineParser &parser)
+{
+	m_hasArgKeepvisibility = parser.isSet("keepvisibility");
+	m_hasArgReset = parser.isSet("failsafe");
+}
