@@ -21,7 +21,6 @@
 
 #include "gui/dialogchoosebackends.h"
 
-#include <qbuttongroup.h>
 #include <QCheckBox>
 #include <QLabel>
 #include <QSet>
@@ -29,9 +28,7 @@
 #include <QVBoxLayout>
 #include <QHBoxLayout>
 
-#include <kcombobox.h>
-#include <kdebug.h>
-#include <klocale.h>
+#include <klocalizedstring.h>
 
 #include "core/ControlManager.h"
 #include "core/GlobalConfig.h"
@@ -54,7 +51,6 @@ DialogChooseBackends::DialogChooseBackends(QWidget* parent, const QSet<QString>&
    _layout = 0;
    m_vboxForScrollView = 0;
    m_scrollableChannelSelector = 0;
-   m_buttonGroupForScrollView = 0;
    createWidgets(mixerIds);
 
 }
@@ -97,7 +93,6 @@ void DialogChooseBackends::createWidgets(const QSet<QString>& mixerIds)
  */
 void DialogChooseBackends::createPage(const QSet<QString>& mixerIds)
 {
-	m_buttonGroupForScrollView = new QButtonGroup(this); // invisible QButtonGroup
 	m_scrollableChannelSelector = new QScrollArea(m_mainFrame);
 
 #ifndef QT_NO_ACCESSIBILITY
@@ -106,15 +101,18 @@ void DialogChooseBackends::createPage(const QSet<QString>& mixerIds)
 
 	_layout->addWidget(m_scrollableChannelSelector);
 
-	m_vboxForScrollView = new KVBox();
+	m_vboxForScrollView = new QWidget();
+	QVBoxLayout *vbl = new QVBoxLayout(m_vboxForScrollView);
+	vbl->setSpacing(0);
 
 	bool hasMixerFilter = !mixerIds.isEmpty();
-	kDebug() << "MixerIds=" << mixerIds;
+	qCDebug(KMIX_LOG) << "MixerIds=" << mixerIds;
 	foreach ( Mixer* mixer, Mixer::mixers())
 	{
 		QCheckBox* qrb = new QCheckBox(mixer->readableName(true), m_vboxForScrollView);
 		qrb->setObjectName(mixer->id());// The object name is used as ID here: see getChosenBackends()
 		connect(qrb, SIGNAL(stateChanged(int)), SLOT(backendsModifiedSlot()));
+                vbl->addWidget(qrb);
 		checkboxes.append(qrb);
 		bool mixerShouldBeShown = !hasMixerFilter || mixerIds.contains(mixer->id());
 		qrb->setChecked(mixerShouldBeShown);
@@ -132,10 +130,10 @@ QSet<QString> DialogChooseBackends::getChosenBackends()
     	if (qcb->isChecked())
     	{
     		newMixerList.insert(qcb->objectName());
-    		kDebug() << "apply found " << qcb->objectName();
+    		qCDebug(KMIX_LOG) << "apply found " << qcb->objectName();
     	}
     }
-    kDebug() << "New list is " << newMixerList;
+    qCDebug(KMIX_LOG) << "New list is " << newMixerList;
     return newMixerList;
 }
 
