@@ -23,19 +23,13 @@
 
 #include <algorithm>
 
-#include <QCheckBox>
 #include <QPushButton>
 #include <QLabel>
-#include <QScrollArea>
 #include <QVBoxLayout>
 #include <QGridLayout>
 
-#include <kdebug.h>
-#include <kdialog.h>
-#include <kicon.h>
-#include <KIconLoader>
-#include <klocale.h>
-#include <kvbox.h>
+#include <kiconloader.h>
+#include <klocalizedstring.h>
 
 #include "gui/guiprofile.h"
 #include "gui/mixdevicewidget.h"
@@ -46,7 +40,7 @@
 DialogViewConfigurationItem::DialogViewConfigurationItem(QListWidget *parent) :
   QListWidgetItem(parent)
 {
-   kDebug() << "DialogViewConfigurationItem() default constructor";
+   qCDebug(KMIX_LOG) << "DialogViewConfigurationItem() default constructor";
    refreshItem();
 }
 
@@ -76,7 +70,7 @@ static QDataStream & operator<< ( QDataStream & s, const DialogViewConfiguration
     s << item._name;
     s << item._splitted;
     s << item._iconName;
- //kDebug() << "<< serialize << " << s;
+ //qCDebug(KMIX_LOG) << "<< serialize << " << s;
     return s;
 }
 
@@ -99,7 +93,7 @@ static QDataStream & operator>> ( QDataStream & s, DialogViewConfigurationItem &
   QString iconName;
   s >> iconName;
   item._iconName = iconName;
- //kDebug() << ">> deserialize >> " << id << name << iconName;
+ //qCDebug(KMIX_LOG) << ">> deserialize >> " << id << name << iconName;
   return s;
 }
 
@@ -156,29 +150,28 @@ bool DialogViewConfigurationWidget::dropMimeData(int index, const QMimeData * mi
     return true;
 }
 
-DialogViewConfiguration::DialogViewConfiguration( QWidget*, ViewBase& view)
-    : KDialog(  0),
+DialogViewConfiguration::DialogViewConfiguration(QWidget *parent, ViewBase &view)
+    : DialogBase(parent),
       _view(view)
 {
-   setCaption( i18n( "Configure Channels" ) );
-   setButtons( Ok|Cancel );
-   setDefaultButton( Ok );
-   frame = new QWidget( this );
+   setWindowTitle( i18n( "Configure Channels" ) );
+   setButtons( QDialogButtonBox::Ok|QDialogButtonBox::Cancel );
+
+   QWidget *frame = new QWidget( this );
    frame->setSizePolicy(QSizePolicy::MinimumExpanding,QSizePolicy::MinimumExpanding);
-   
    setMainWidget( frame );
    
    // The _layout will hold two items: The title and the Drag-n-Drop area
-   _layout = new QVBoxLayout(frame );
-   _layout->setMargin( 0 );
-   _layout->setSpacing(KDialog::spacingHint());
+   QVBoxLayout *layout = new QVBoxLayout(frame);
+   layout->setMargin( 0 );
+   layout->setSpacing(DialogBase::verticalSpacing());
    
    // --- HEADER ---
-   qlb = new QLabel( i18n("Configuration of the channels. Drag icon to update."), frame );
-   _layout->addWidget(qlb);
+   QLabel *qlb = new QLabel( i18n("Configure the visible channels. Drag icons between the lists to update."), frame );
+   layout->addWidget(qlb);
    
    _glayout = new QGridLayout();
-   _layout->addLayout(_glayout);
+   layout->addLayout(_glayout);
 
    _qlw = 0;
    _qlwInactive = 0;
@@ -192,12 +185,12 @@ DialogViewConfiguration::DialogViewConfiguration( QWidget*, ViewBase& view)
  */
 void DialogViewConfiguration::slotDropped ( DialogViewConfigurationWidget* list, int index, DialogViewConfigurationItem* item, bool sourceIsActiveList )
 {
-//kDebug() << "dropped item (index" << index << "): " << item->_id << item->_shown << item->_name << item->_splitted << item->_iconName;
+//qCDebug(KMIX_LOG) << "dropped item (index" << index << "): " << item->_id << item->_shown << item->_name << item->_splitted << item->_iconName;
 
     if ( list == _qlw ) {
         //DialogViewConfigurationItem* after = index > 0 ? static_cast<DialogViewConfigurationItem *>(list->item(index-1)) : 0;
 
-        //kDebug() << "after" << after->text() << after->internalTag();
+        //qCDebug(KMIX_LOG) << "after" << after->text() << after->internalTag();
         if ( sourceIsActiveList ) {
             // has been dragged within the active list (moved).
             _qlw->insertItem ( index, item );
@@ -266,12 +259,13 @@ void DialogViewConfiguration::createPage()
 {
    QList<QWidget *> &mdws = _view._mdws;
 
-   QLabel *l1 = new QLabel( i18n("Visible channels") );
+   QLabel *l1 = new QLabel( i18n("Visible channels:") );
    _glayout->addWidget(l1,0,0);
       
-   QLabel *l2 = new QLabel( i18n("Available channels") );
+   QLabel *l2 = new QLabel( i18n("Available channels:") );
    _glayout->addWidget(l2,0,6);
 
+   QWidget *frame = mainWidget();
    _qlwInactive = new DialogViewConfigurationWidget(frame);
    _qlwInactive->setDragDropMode(QAbstractItemView::DragDrop);
    _qlwInactive->setActiveList(false);
@@ -280,16 +274,18 @@ void DialogViewConfiguration::createPage()
            this  ,         SLOT(slotDropped(DialogViewConfigurationWidget*,int,DialogViewConfigurationItem*,bool)));
    
    addSpacer(1,1);
-   const KIcon& icon = KIcon( QLatin1String( "arrow-left" ));
+   const QIcon& icon = QIcon::fromTheme( QLatin1String( "arrow-left" ));
     moveLeftButton = new QPushButton(icon, "");
     moveLeftButton->setEnabled(false);
+    moveLeftButton->setToolTip(i18n("Move the selected channel to the visible list"));
    _glayout->addWidget(moveLeftButton,1,2);
    connect(moveLeftButton, SIGNAL(clicked(bool)), SLOT(moveSelectionToActiveList()));
    addSpacer(1,3);
 
-   const KIcon& icon2 = KIcon( QLatin1String( "arrow-right" ));
+   const QIcon& icon2 = QIcon::fromTheme( QLatin1String( "arrow-right" ));
     moveRightButton = new QPushButton(icon2, "");
     moveRightButton->setEnabled(false);
+    moveRightButton->setToolTip(i18n("Move the selected channel to the available (hidden) list"));
    _glayout->addWidget(moveRightButton,1,4);
    connect(moveRightButton, SIGNAL(clicked(bool)), SLOT(moveSelectionToInactiveList()));
    addSpacer(1,5);
@@ -315,7 +311,7 @@ void DialogViewConfiguration::createPage()
                splitted =  ( md->playbackVolume().count() > 1) || ( md->captureVolume().count() > 1 ) ;
             }
 
-            //kDebug()  << "add DialogViewConfigurationItem: " << mdName << " visible=" << mdw->isVisible() << "splitted=" << splitted;
+            //qCDebug(KMIX_LOG)  << "add DialogViewConfigurationItem: " << mdName << " visible=" << mdw->isVisible() << "splitted=" << splitted;
             if ( mdw->isVisible() ) {
               new DialogViewConfigurationItem(_qlw, md->id(), mdw->isVisible(), mdName, splitted, mdw->mixDevice()->iconName());
             }
@@ -359,7 +355,7 @@ void DialogViewConfiguration::createPage()
 
 //   scrollArea->updateGeometry();
    updateGeometry();
-   connect( this, SIGNAL(okClicked())   , this, SLOT(apply()) );
+   connect(this, SIGNAL(accepted()), this, SLOT(apply()));
 
 #ifndef QT_NO_ACCESSIBILITY
     moveLeftButton->setAccessibleName( i18n("Show the selected channel") );
@@ -438,10 +434,10 @@ void DialogViewConfiguration::prepareControls(QAbstractItemModel* model, bool is
 
 
          // -3- Insert it in the new ControlSet **************************
-//         kDebug() << "Should add to new ControlSet: " << ctlId;
+//         qCDebug(KMIX_LOG) << "Should add to new ControlSet: " << ctlId;
         foreach ( ProfControl* control, oldCtlSet)
         {
-            //kDebug() << " checking " << control->id;
+            //qCDebug(KMIX_LOG) << " checking " << control->id;
             QRegExp idRegexp(control->id);
             if ( ctlId.contains(idRegexp) ) {
                 // found. Create a copy
@@ -451,7 +447,7 @@ void DialogViewConfiguration::prepareControls(QAbstractItemModel* model, bool is
                 newCtl->setMandatory(false);
                 newCtl->setVisible(isActiveView);
                 newCtlSet.push_back(newCtl);
-//                 kDebug() << "Added to new ControlSet (done): " << newCtl->id;
+//                 qCDebug(KMIX_LOG) << "Added to new ControlSet (done): " << newCtl->id;
                 break;
             }
         }
