@@ -24,24 +24,24 @@
 #include <QDir>
 #include <qxml.h>
 #include <QString>
+#include <QStandardPaths>
 
 // System
 #include <iostream>
 #include <utility>
 
-// KDE
-#include <kdebug.h>
-#include <kstandarddirs.h>
-
 // KMix
 #include "core/mixer.h"
-#include <QtCore/qstring.h>
 
 QMap<QString, GUIProfile*> GUIProfile::s_profiles;
-QString const GUIProfile::PNameSimple("simple");
-QString const GUIProfile::PNameExtended("extended");
-QString const GUIProfile::PNameAll("all");
-QString const GUIProfile::PNameCustom("custom");
+
+GuiVisibility const GuiVisibility::GuiSIMPLE  (QString("simple"  ) , GuiVisibility::SIMPLE);
+GuiVisibility const GuiVisibility::GuiEXTENDED(QString("extended") , GuiVisibility::EXTENDED);
+// For backwards compatibility, GuiFULL has the ID "all", and not "full"
+GuiVisibility const GuiVisibility::GuiFULL    (QString("all"     ) , GuiVisibility::FULL);
+GuiVisibility const GuiVisibility::GuiCUSTOM  (QString("custom"  ) , GuiVisibility::CUSTOM);
+GuiVisibility const GuiVisibility::GuiNEVER   (QString("never"   ) , GuiVisibility::NEVER);
+
 
 bool SortedStringComparator::operator()(const std::string& s1, const std::string& s2) const {
     return ( s1 < s2 );
@@ -87,7 +87,7 @@ GUIProfile::GUIProfile()
 
 GUIProfile::~GUIProfile()
 {
-    kWarning() << "Thou shalt not delete any GUI profile. This message is only OK, when quitting KMix";
+    qCWarning(KMIX_LOG) << "Thou shalt not delete any GUI profile. This message is only OK, when quitting KMix";
     qDeleteAll(_controls);
     qDeleteAll(_products);
 }
@@ -160,7 +160,7 @@ QString GUIProfile::buildReadableProfileName(Mixer* mixer, QString profileName)
         fname += ' ' + profileName;
     }
 
-    kDebug() << fname;
+    qCDebug(KMIX_LOG) << fname;
     return fname;
 }
 
@@ -203,10 +203,10 @@ GUIProfile* GUIProfile::find(Mixer* mixer, QString profileName, bool profileName
     if ( mixer == 0 || profileName.isEmpty() )
         return 0;
 
-    if ( mixer->isDynamic() ) {
-        kDebug(67100) << "GUIProfile::find() Not loading GUIProfile for Dynamic Mixer (e.g. PulseAudio)";
-        return 0;
-    }
+//    if ( mixer->isDynamic() ) {
+//        qCDebug(KMIX_LOG) << "GUIProfile::find() Not loading GUIProfile for Dynamic Mixer (e.g. PulseAudio)";
+//        return 0;
+//    }
 
     QString requestedProfileName;
     QString fullQualifiedProfileName;
@@ -261,7 +261,7 @@ void GUIProfile::addProfile(GUIProfile* guiprof)
 	//                a XML gui profile (so the Cached version is retrieved, and addProfile() is not called).
 
     s_profiles[guiprof->getId()] = guiprof;
-    kDebug() << "I have added" << guiprof->getId() << "; Number of profiles is now " <<  s_profiles.size() ;
+    qCDebug(KMIX_LOG) << "I have added" << guiprof->getId() << "; Number of profiles is now " <<  s_profiles.size() ;
 }
 
 
@@ -276,7 +276,7 @@ GUIProfile* GUIProfile::loadProfileFromXMLfiles(Mixer* mixer, QString profileNam
 {
     GUIProfile* guiprof = 0;
     QString fileName = createNormalizedFilename(profileName);
-    QString fileNameFQ = KStandardDirs::locate("appdata", fileName );
+    QString fileNameFQ = QStandardPaths::locate(QStandardPaths::DataLocation, fileName );
 
     if ( ! fileNameFQ.isEmpty() ) {
         guiprof = new GUIProfile();
@@ -289,7 +289,7 @@ GUIProfile* GUIProfile::loadProfileFromXMLfiles(Mixer* mixer, QString profileNam
         }
     }
     else {
-        kDebug() << "Ignore file " <<fileName<< " (does not exist)";
+        qCDebug(KMIX_LOG) << "Ignore file " <<fileName<< " (does not exist)";
     }
     return guiprof;
 }
@@ -350,7 +350,7 @@ GUIProfile* GUIProfile::fallbackProfile(Mixer *mixer)
 bool GUIProfile::readProfile(const QString& ref_fileName)
 {
     QXmlSimpleReader *xmlReader = new QXmlSimpleReader();
-    kDebug() << "Read profile:" << ref_fileName ;
+    qCDebug(KMIX_LOG) << "Read profile:" << ref_fileName ;
     QFile xmlFile( ref_fileName );
     QXmlInputSource source( &xmlFile );
     GUIProfileParser* gpp = new GUIProfileParser(this);
@@ -363,7 +363,7 @@ bool GUIProfile::readProfile(const QString& ref_fileName)
     } // Read OK
     else {
         // !! this error message about faulty profiles should probably be surrounded with i18n()
-        kError(67100) << "ERROR: The profile '" << ref_fileName<< "' contains errors, and is not used." << endl;
+        qCCritical(KMIX_LOG) << "ERROR: The profile '" << ref_fileName<< "' contains errors, and is not used.";
     }
     delete gpp;
     delete xmlReader;
@@ -386,9 +386,9 @@ bool GUIProfile::writeProfile()
    bool ret = false;
    QString profileId = getId();
    QString fileName = createNormalizedFilename(profileId);
-   QString fileNameFQ = KStandardDirs::locateLocal("appdata", fileName, true );
+   QString fileNameFQ = QStandardPaths::writableLocation(QStandardPaths::DataLocation) + '/' + fileName;
 
-   kDebug() << "Write profile:" << fileNameFQ ;
+   qCDebug(KMIX_LOG) << "Write profile:" << fileNameFQ ;
    QFile f(fileNameFQ);
    if ( f.open(QIODevice::WriteOnly | QFile::Truncate) )
    { 
@@ -505,20 +505,20 @@ QString xmlify(QString raw);
 
 QString xmlify(QString raw)
 {
-// 	kDebug() << "Before: " << raw;
+// 	qCDebug(KMIX_LOG) << "Before: " << raw;
 	raw = raw.replace('&', "&amp;");
 	raw = raw.replace('<', "&lt;");
 	raw = raw.replace('>', "&gt;");
 	raw = raw.replace("'", "&apos;");
 	raw = raw.replace("\"", "&quot;");
-// 	kDebug() << "After : " << raw;
+// 	qCDebug(KMIX_LOG) << "After : " << raw;
 	return raw;
 }
 
 
 QTextStream& operator<<(QTextStream &os, const GUIProfile& guiprof)
 {
-// kDebug() << "ENTER QTextStream& operator<<";
+// qCDebug(KMIX_LOG) << "ENTER QTextStream& operator<<";
    os << "<?xml version=\"1.0\" encoding=\"utf-8\"?>";
    os << endl << endl;
 
@@ -552,7 +552,7 @@ QTextStream& operator<<(QTextStream &os, const GUIProfile& guiprof)
 		  os << " name=\"" << xmlify(profControl->name).toUtf8().constData() << "\"" ;
 		}
 		os << " subcontrols=\"" << xmlify( profControl->renderSubcontrols().toUtf8().constData()) << "\"" ;
-		os << " show=\"" << xmlify(profControl->show).toUtf8().constData() << "\"" ;
+		os << " show=\"" << xmlify(profControl->getVisibility().getId().toUtf8().constData()) << "\"" ;
 		if ( profControl->isMandatory() ) {
 		  os << " mandatory=\"true\"";
 		}
@@ -564,7 +564,7 @@ QTextStream& operator<<(QTextStream &os, const GUIProfile& guiprof)
 	os << endl;
 
 	os << "</soundcard>" << endl;
-// kDebug() << "EXIT  QTextStream& operator<<";
+// qCDebug(KMIX_LOG) << "EXIT  QTextStream& operator<<";
 	return os;
 }
 
@@ -614,15 +614,16 @@ std::ostream& operator<<(std::ostream& os, const GUIProfile& guiprof) {
 }
 
 ProfControl::ProfControl(QString& id, QString& subcontrols ) :
-	  _mandatory(false), _split(false) {
+		visibility(GuiVisibility::GuiSIMPLE), _mandatory(false), _split(false)
+{
     d = new ProfControlPrivate();
-    this->show = "simple";
     this->id = id;
     setSubcontrols(subcontrols);
 }
 
 ProfControl::ProfControl(const ProfControl &profControl) :
-	  _mandatory(false), _split(false) {
+		visibility(profControl.visibility), _mandatory(false), _split(false)
+{
     d = new ProfControlPrivate();
     id = profControl.id;
     name = profControl.name;
@@ -635,7 +636,6 @@ ProfControl::ProfControl(const ProfControl &profControl) :
     d->subcontrols = profControl.d->subcontrols;
 
     name = profControl.name;
-    show = profControl.show;
     backgroundColor = profControl.backgroundColor;
     switchtype = profControl.switchtype;
     _mandatory = profControl._mandatory;
@@ -646,9 +646,20 @@ ProfControl::~ProfControl() {
     delete d;
 }
 
+/**
+ * An overridden method for #setVisible(const GuiVisibility&), that either sets GuiVisibility::GuiSIMPLE
+ * or GuiVisibility::GuiNEVER;
+ *
+ * @param visible
+ */
 void ProfControl::setVisible(bool visible)
 {
-	show = visible ? GUIProfile::PNameSimple : GUIProfile::PNameExtended;
+	this->visibility = visible ? GuiVisibility::GuiSIMPLE : GuiVisibility::GuiNEVER;
+}
+
+void ProfControl::setVisible(const GuiVisibility& visibility)
+{
+	this->visibility = visibility;
 }
 
 void ProfControl::setSubcontrols(QString sctls)
@@ -665,7 +676,7 @@ void ProfControl::setSubcontrols(QString sctls)
   QStringListIterator qslIt(qsl);
   while (qslIt.hasNext()) {
     QString sctl = qslIt.next();
-       //kDebug() << "setSubcontrols found: " << sctl.toLocal8Bit().constData() << endl;
+       //qCDebug(KMIX_LOG) << "setSubcontrols found: " << sctl.toLocal8Bit().constData();
        if ( sctl == "pvolume" ) _useSubcontrolPlayback = true;
        else if ( sctl == "cvolume" ) _useSubcontrolCapture = true;
        else if ( sctl == "pswitch" ) _useSubcontrolPlaybackSwitch = true;
@@ -678,7 +689,7 @@ void ProfControl::setSubcontrols(QString sctls)
 	 _useSubcontrolPlaybackSwitch = true;
 	 _useSubcontrolEnum = true;
        }
-       else kWarning() << "Ignoring unknown subcontrol type '" << sctl << "' in profile";
+       else qCWarning(KMIX_LOG) << "Ignoring unknown subcontrol type '" << sctl << "' in profile";
   }
 }
 
@@ -884,7 +895,7 @@ void GUIProfileParser::addControl(const QXmlAttributes& attributes) {
         if ( show.isNull() ) { show = '*'; }
 
 	profControl->name = name;
-	profControl->show = show;
+	profControl->setVisible(GuiVisibility::getByString(show));
 	profControl->setBackgroundColor( background );
 	profControl->setSwitchtype(switchtype);
 	profControl->setMandatory(isMandatory);
