@@ -25,17 +25,13 @@
 #include <qevent.h>
 #include <qframe.h>
 #include <QGridLayout>
+#include <QIcon>
 #include <QLayoutItem>
 #include <QPushButton>
 #include <QSizePolicy>
 
 // KDE
-#include <kaction.h>
-#include <kapplication.h>
-#include <kdebug.h>
-#include <kdialog.h>
-#include <kicon.h>
-#include <klocale.h>
+#include <klocalizedstring.h>
 #include <kwindowsystem.h>
 
 // KMix
@@ -47,6 +43,7 @@
 #include "gui/guiprofile.h"
 #include "gui/kmixprefdlg.h"
 #include "gui/mdwslider.h"
+#include "dialogbase.h"
 
 // Restore volume button feature is incomplete => disabling for KDE 4.10
 #undef RESTORE_VOLUME_BUTTON
@@ -88,7 +85,7 @@ ViewDockAreaPopup::ViewDockAreaPopup(QWidget* parent, QString id, ViewBase::View
 		// The list will be redone in _setMixSet() with the actual Mixer instances to use
 	}
 
-	restoreVolumeIcon = new KIcon(QLatin1String("quickopen-file"));
+	restoreVolumeIcon = QIcon::fromTheme(QLatin1String("quickopen-file"));
 	createDeviceWidgets();
 
 	// Register listeners for all mixers
@@ -103,7 +100,6 @@ ViewDockAreaPopup::~ViewDockAreaPopup()
 {
   ControlManager::instance().removeListener(this);
   delete _layoutMDW;
-  delete restoreVolumeIcon;
   // Hint: optionsLayout and "everything else" is deleted when "delete _layoutMDW" cascades down
 }
 
@@ -137,11 +133,6 @@ void ViewDockAreaPopup::wheelEvent ( QWheelEvent * e )
 {
   if ( _mdws.isEmpty() )
     return;
-
-#ifndef X_KMIX_KF5_BUILD
-   // Pass wheel event from "border widget" to child
-   QApplication::sendEvent( _mdws.first(), e);
-#endif
 }
 
 
@@ -232,7 +223,7 @@ Application: KMix (kmix), signal: Segmentation fault
 	 */
 	delete layout(); // BKO 299754
 	_layoutMDW = new QGridLayout(this);
-	_layoutMDW->setSpacing(KDialog::spacingHint());
+	_layoutMDW->setSpacing(DialogBase::verticalSpacing());
 	// Review #121166: Add some space over device icons, otherwise they may hit window border
 	_layoutMDW->setContentsMargins(0,5,0,0);
 	//_layoutMDW->setSizeConstraint(QLayout::SetMinimumSize);
@@ -245,7 +236,7 @@ Application: KMix (kmix), signal: Segmentation fault
 	_mixers.clear();
 
 	QSet<QString> preferredMixersForSoundmenu = GlobalConfig::instance().getMixersForSoundmenu();
-//	kDebug() << "Launch with " << preferredMixersForSoundmenu;
+//	qCDebug(KMIX_LOG) << "Launch with " << preferredMixersForSoundmenu;
 	foreach ( Mixer* mixer, Mixer::mixers() )
 	{
 		bool useMixer = preferredMixersForSoundmenu.isEmpty() || preferredMixersForSoundmenu.contains(mixer->id());
@@ -268,7 +259,7 @@ Application: KMix (kmix), signal: Segmentation fault
 	// A loop that adds the Master control of each card
 	foreach ( Mixer* mixer, _mixers )
 	{
-//		kDebug() << "ADD? mixerId=" << mixer->id();
+//		qCDebug(KMIX_LOG) << "ADD? mixerId=" << mixer->id();
 		shared_ptr<MixDevice>dockMD = mixer->getLocalMasterMD();
 		if ( !dockMD && mixer->size() > 0 )
 		{
@@ -277,10 +268,10 @@ Application: KMix (kmix), signal: Segmentation fault
 		}
 		if ( dockMD )
 		{
-//			kDebug() << "ADD? mixerId=" << mixer->id() << ", md=" << dockMD->id();
+//			qCDebug(KMIX_LOG) << "ADD? mixerId=" << mixer->id() << ", md=" << dockMD->id();
 			if ( !dockMD->isApplicationStream() && dockMD->playbackVolume().hasVolume())
 			{
-//				kDebug() << "ADD? mixerId=" << mixer->id() << ", md=" << dockMD->id() << ": YES";
+//				qCDebug(KMIX_LOG) << "ADD? mixerId=" << mixer->id() << ", md=" << dockMD->id() << ": YES";
 				// don't add application streams here. They are handled below, so
 				// we make sure to not add them twice
 				_mixSet.append(dockMD);
@@ -365,16 +356,17 @@ _layoutMDW->addWidget( seperatorBetweenMastersAndStreams, row, col );
    
    _layoutMDW->addWidget( mdw, row, col );
 
-   //kDebug(67100) << "ADDED " << md->id() << " at column " << sliderColumn;
+   //qCDebug(KMIX_LOG) << "ADDED " << md->id() << " at column " << sliderColumn;
    return mdw;
 }
 
 void ViewDockAreaPopup::constructionFinished()
 {
-//   kDebug(67100) << "ViewDockAreaPopup::constructionFinished()\n";
+//   qCDebug(KMIX_LOG) << "ViewDockAreaPopup::constructionFinished()\n";
 
-	mainWindowButton = new QPushButton(i18n("Mixer"), this);
+	mainWindowButton = new QPushButton(QIcon::fromTheme("show-mixer"), "" , this);
 	mainWindowButton->setObjectName(QLatin1String("MixerPanel"));
+	mainWindowButton->setToolTip(i18n("Show the full mixer window"));
 	connect(mainWindowButton, SIGNAL(clicked()), SLOT(showPanelSlot()));
 
 	configureViewButton = createConfigureViewButton();
@@ -401,15 +393,15 @@ void ViewDockAreaPopup::constructionFinished()
 	_layoutMDW->activate();
 
     //bool fnc = focusNextChild();
-    //kWarning() << "fnc=" <<fnc;
+    //qCWarning(KMIX_LOG) << "fnc=" <<fnc;
 
-//	kDebug() << "F layout()=" << layout() << ", _layoutMDW=" << _layoutMDW;
+//	qCDebug(KMIX_LOG) << "F layout()=" << layout() << ", _layoutMDW=" << _layoutMDW;
 }
 
 QPushButton* ViewDockAreaPopup::createRestoreVolumeButton ( int storageSlot )
 {
 	QString buttonText = QString("%1").arg(storageSlot);
-	QPushButton* profileButton = new QPushButton(*restoreVolumeIcon, buttonText, this);
+	QPushButton* profileButton = new QPushButton(restoreVolumeIcon, buttonText, this);
 	profileButton->setToolTip(i18n("Load volume profile %1").arg(storageSlot));
 	profileButton->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
 	return profileButton;
@@ -419,7 +411,7 @@ void ViewDockAreaPopup::refreshVolumeLevels()
 {
   foreach ( QWidget* qw, _mdws )
   {
-    //kDebug() << "rvl: " << qw;
+    //qCDebug(KMIX_LOG) << "rvl: " << qw;
     MixDeviceWidget* mdw = qobject_cast<MixDeviceWidget*>(qw);
     if ( mdw != 0 ) mdw->update();
   }
