@@ -24,12 +24,22 @@
 #define VOLUMESLIDER_H
 
 #include <QSlider>
+#include <QLabel>
+#include <QMouseEvent>
 
 #include "volumesliderextradata.h"
 
 class VolumeSlider : public QSlider
 {
       Q_OBJECT
+	Qt::Orientation m_orientation;
+	QLabel* m_tooltip;
+
+protected:
+	void mousePressEvent(QMouseEvent *event) Q_DECL_OVERRIDE;
+	void mouseMoveEvent(QMouseEvent *event) Q_DECL_OVERRIDE;
+	void mouseReleaseEvent(QMouseEvent *event) Q_DECL_OVERRIDE;
+
 public:
       VolumeSlider(Qt::Orientation orientation, QWidget* parent); // : QSlider(orientation, parent);
 
